@@ -5,6 +5,7 @@ use warnings;
 
 use JSON;
 use Encode;
+use Readonly;
 use Scalar::Util qw(looks_like_number);
 use Text::Trim;
 use LWP::RobotUA;
@@ -14,19 +15,19 @@ use HTML::TreeBuilder::XPath;
 use Moose;
 use MooseX::Privacy;
 
-use FilmAffinity::Utils;
+use FilmAffinity::Utils qw/buildRobot/;
 
-=head1 NAME - FilmAffinity::Movie
+=head1 NAME
 
 FilmAffinity::Movie - Perl interface to FilmAffinity
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 =head1 SYNOPSIS
 
@@ -34,7 +35,7 @@ Retrieve information about a filmaffinity movie
 
     use FilmAffinity::Movie;
 
-    my $movie = FilmAffinity::Movie->new( 
+    my $movie = FilmAffinity::Movie->new(
       id    => $movieID,
       delay => $delay || 5,
     );
@@ -47,7 +48,7 @@ Via the command-line program filmaffinity-get-movie-info.pl
 
 =head2 Overview
 
-FilmAffinity::Movie is a Perl interface to FilmAffinity. You can use 
+FilmAffinity::Movie is a Perl interface to FilmAffinity. You can use
 this module to retrieve information about a movie.
 
 =head2 Constructor
@@ -57,9 +58,9 @@ this module to retrieve information about a movie.
 =item new()
 
 Object's constructor. You should pass as parameter the movieID
- 
-    my $movie = FilmAffinity::Movie->new( id => '932476' ); 
-    
+
+    my $movie = FilmAffinity::Movie->new( id => '932476' );
+
 =back
 
 =head2 Options
@@ -70,13 +71,13 @@ Object's constructor. You should pass as parameter the movieID
 
 Set the minimum delay between requests to the server, in seconds.
 
-    my $parser = FilmAffinity::Movie->new( 
+    my $parser = FilmAffinity::Movie->new(
       userID => '932476',
       delay  => 20,
     );
-    
-By default, the delay is 5 seconds 
-    
+
+By default, the delay is 5 seconds
+
 =back
 
 =head1 ACCESSORS
@@ -189,119 +190,128 @@ has studio   => ( is => 'rw', isa => 'ArrayRef[Str]', );
 has producer => ( is => 'rw',  );
 
 
-has tree => ( 
+has tree => (
   is      => 'rw',
   isa     => 'HTML::TreeBuilder',
   traits  => [qw/Private/],
-); 
+);
 
-has ua => ( 
+has ua => (
   is      => 'rw',
   isa     => 'LWP::RobotUA',
   traits  => [qw/Private/],
-); 
+);
 
-my $MOVIE_URL = 'http://www.filmaffinity.com/en/film';
+my $MOVIE_URL     = 'http://www.filmaffinity.com/en/film';
+my $XPATH_TITLE   = '//h1[@id="main-title"]';
+my $XPATH_RATING  = '//div[@id="movie-rat-avg"]';
+my $XPATH_VOTE    = '//div[@id="movie-count-rat"]/span';
+my $XPATH_COUNTRY = '//span[@id="country-img"]/img/@title';
+my $XPATH_COVER   = '//div[@id="movie-main-image-container"]/a/img/@src';
 
-my @JSON_FIELD = (
-  'id', 'title', 'year', 'synopsis', 'website', 'duration', 'cast' , 'director',
-  'composer', 'screenwriter', 'cinematographer', 'genre', 'topic', 'studio', 
-  'producer', 'country', 'cover', 'rating', 'votes', 'originaltitle',
+my @JSON_FIELD = qw(
+  id title year synopsis website duration cast director composer screenwriter
+  cinematographer genre topic studio producer country cover rating votes
+  originaltitle
 );
 
 my $FIELD = [
-  { 
-    accessor => 'originaltitle', 
-    faTag    => 'ORIGINAL TITLE', 
-  },
-  { 
-    accessor => 'year', 
-    faTag    => 'YEAR', 
-  },
-  { 
-    accessor => 'synopsis', 
-    faTag    => 'SYNOPSIS/PLOT', 
-  },
-  { 
-    accessor => 'website', 
-    faTag    => 'OFFICIAL WEB', 
-  },  
   {
-    accessor   => 'duration', 
-    faTag      => 'RUNNING TIME', 
-    cleanerSub => \&p_cleanDuration, 
+    accessor => 'originaltitle',
+    faTag    => 'Original title',
   },
-  { 
-    accessor   => 'cast', 
-    faTag      => 'CAST', 
-    cleanerSub => \&p_cleanPerson, 
+  {
+    accessor => 'year',
+    faTag    => 'Year',
   },
-  { 
-    accessor   => 'director', 
-    faTag      => 'DIRECTOR',     
+  {
+    accessor => 'synopsis',
+    faTag    => 'Synopsis / Plot',
+  },
+  {
+    accessor => 'website',
+    faTag    => 'Official Site',
+  },
+  {
+    accessor   => 'duration',
+    faTag      => 'Running Time',
+    cleanerSub => \&p_cleanDuration,
+  },
+  {
+    accessor   => 'cast',
+    faTag      => 'Cast',
     cleanerSub => \&p_cleanPerson,
   },
-  { 
-    accessor   => 'composer', 
-    faTag      => 'COMPOSER',     
-    cleanerSub => \&p_cleanPerson,
-  },  
-  { 
-    accessor   => 'screenwriter', 
-    faTag      => 'SCREENWRITER',    
+  {
+    accessor   => 'director',
+    faTag      => 'Director',
     cleanerSub => \&p_cleanPerson,
   },
-  { 
-    accessor   => 'cinematographer', 
-    faTag      => 'CINEMATOGRAPHER', 
+  {
+    accessor   => 'composer',
+    faTag      => 'Music',
     cleanerSub => \&p_cleanPerson,
   },
-  { 
-    accessor   => 'genre', 
-    faTag      => 'GENRE', 
-    cleanerSub => \&p_cleanGenre, 
+  {
+    accessor   => 'screenwriter',
+    faTag      => 'Screenwriter',
+    cleanerSub => \&p_cleanPerson,
   },
-  { 
-    accessor   => 'topic', 
-    faTag      => 'GENRE', 
-    cleanerSub => \&p_cleanGenre, 
-  }, 
-  { 
-    accessor   => 'studio', 
-    faTag      => 'STUDIO/PRODUCER', 
+  {
+    accessor   => 'cinematographer',
+    faTag      => 'Cinematography',
+    cleanerSub => \&p_cleanPerson,
+  },
+  {
+    accessor   => 'genre',
+    faTag      => 'Genre',
+    cleanerSub => \&p_cleanGenre,
+  },
+  {
+    accessor   => 'topic',
+    faTag      => 'Genre',
+    cleanerSub => \&p_cleanGenre,
+  },
+  {
+    accessor   => 'studio',
+    faTag      => 'Production Co.',
     cleanerSub => \&p_cleanStudio,
   },
-  { 
-    accessor   => 'producer' , 
-    faTag      => 'STUDIO/PRODUCER', 
-    cleanerSub => \&p_cleanStudio, 
+  {
+    accessor   => 'producer' ,
+    faTag      => 'Production Co.',
+    cleanerSub => \&p_cleanStudio,
   },
 ];
 
+Readonly my $SECONDS => 5;
+
 sub BUILD {
   my ($self, $args) = @_;
- 
-  $self->tree( HTML::TreeBuilder->new() );
-  $self->ua( buildRobot( $args->{delay} || 5 ) );
-} 
 
-=head1 METHODS
+  $self->tree( HTML::TreeBuilder->new() );
+  $self->ua( buildRobot( $args->{delay} || $SECONDS ) );
+  return;
+}
+
+=head1 SUBROUTINES/METHODS
 
 =head2 $movie->parse()
 
 This method will get the content of the filmaffinity webpage and retrieve
 all information about the movie
 
-=cut 
+=cut
 
 sub parse {
   my $self = shift;
-  
+
   my $content = $self->getContent();
   $self->parsePage($content);
+  return;
 }
 
-   
+
 =head2 $movie->getContent()
 
 This method will get the content of the filmaffinity webpage
@@ -310,37 +320,40 @@ This method will get the content of the filmaffinity webpage
 
 sub getContent {
   my ($self) = @_;
-  
+
   my $url = $self->p_buildUrlMovie($self->id);
 
   my $response = $self->ua->get($url);
   if ($response->is_success){
-    return $response->decoded_content();
+    return $response->content();
   }
 }
 
 =head2 $movie->parsePage($content)
 
-This method parses a page of filmaffinity that is available as 
-a single string in memory. 
+This method parses a page of filmaffinity that is available as
+a single string in memory.
+
+=cut
 
-=cut  
-  
 sub parsePage {
   my ($self, $content) = @_;
-  
-  $content = decode('cp1252', $content);
+
+  $content = decode('utf-8', $content);
   $self->tree->parse($content);
 
   foreach my $data (@{$FIELD}){
     $self->p_findField($data);
   }
-  $self->p_findCountryAndCover(); 
-  $self->p_findRating(); 
-  $self->p_findVotes(); 
-  $self->p_findTitle();
+
+  $self->p_findRating();
+  $self->p_findVotes();
+  $self->country( $self->tree->findvalue( $XPATH_COUNTRY ) );
+  $self->cover( $self->tree->findvalue( $XPATH_COVER ) );
+  $self->title( $self->tree->findvalue( $XPATH_TITLE ) );
 
   $self->tree->delete();
+  return;
 }
 
 
@@ -349,45 +362,40 @@ sub parsePage {
 
 This method will export all movie informations in JSON format
 
-=cut 
+=cut
 
 sub toJSON {
   my $self = shift;
-  
+
   my %data;
   foreach my $field (@JSON_FIELD){
-    $data{$field} = $self->$field() if defined $self->$field(); 
+    $data{$field} = $self->$field() if defined $self->$field();
   };
-  
+
   return to_json(\%data, {pretty => 1});
 }
- 
+
 private_method p_findField => sub {
   my ( $self, $data ) = @_;
-  
-  my @nodes = $self->tree->findnodes( '//td/b' );
+
+  my @nodes = $self->tree->findnodes( '//dl[@class="movie-info"]/dt' );
   foreach my $node (@nodes){
     if ( trim( $node->as_text() ) eq $data->{faTag} ){
-      
-      my $searched_node = $node->parent()->right();
-      my $td = $searched_node->look_down( 
-        _tag  => 'td', 
-        align => undef,
-        sub { $_[0]->as_HTML() !~ m/<table(.*)>/ }
-      );
-      
+
+      my $searched_node = $node->right();
+
       my $accessor = $data->{accessor};
 
-      my $value = trim( demoronize( $td->as_text() ) );
-      
-      next if $value eq '';
+      my $value = trim( $searched_node->as_text() );
+
+      next if $value eq q{};
 
       if (defined $data->{cleanerSub}){
         $value = $data->{cleanerSub}($value, $accessor);
       }
-      
+
       next if not defined $value;
-      
+
       $self->$accessor( $value );
       last;
     }
@@ -396,122 +404,88 @@ private_method p_findField => sub {
 
 private_method p_findRating => sub {
   my $self = shift;
-    
-  my $rating = $self->tree->look_down( 
-    _tag  => 'td', 
-    align => 'center',
-    style => qr/font-size:22px/,
-  );
-  
-  return if not defined $rating;
-  $self->rating( $rating->as_text() );
-};
 
-private_method p_findTitle => sub {
-  my $self = shift;  
-  
-  my @images =  $self->tree->findnodes( '//span/img' );
-  foreach my $image (@images){
-    if ( $image->attr('src') =~ m/movie.gif/ ){
-      $self->title(  trim($image->parent()->as_text()) ); 
-    }  
-  }
+  my $rating = $self->tree->findvalue( $XPATH_RATING );
+
+  return if not defined $rating or $rating eq q{};
+  $self->rating( trim($rating) );
 };
 
 private_method p_findVotes => sub {
   my $self = shift;
-  
-  my $votes = $self->tree->look_down( 
-    _tag  => 'td', 
-    align => 'center',
-    sub { $_[0]->as_text() =~ m/votes/ }
-  );
-  
-  return if not defined $votes; 
-  $votes = $votes->as_text();
-  $votes =~ s/\D//gi;
-  $self->votes( $votes );
-};
 
-private_method p_findCountryAndCover => sub {
-  my $self = shift;
-  
-  my @images =  $self->tree->findnodes( '//img' );
-  foreach my $image (@images){
-    if ($image->attr('src') =~ m{/imgs/countries/}){        
-      $self->country( $image->attr('title') );
-    }  
-    if ($image->attr('src') =~ m/pics\.filmaffinity\.com/){        
-      $self->cover( $image->attr('src') );
-    }  
-  }
+  my $votes = $self->tree->findvalue( $XPATH_VOTE );
+
+  return if not defined $votes or $votes eq q{};
+  $votes =~ s/\D//gixms;
+  $self->votes( trim($votes) );
 };
 
 private_method p_buildUrlMovie => sub {
   my ($self, $id) = @_;
-    
+
   return $MOVIE_URL.$id.'.html';
 };
 
 private_method p_removeTextBetweenParenthesis => sub {
   my $content = shift;
-  
-  $content =~ s/\(.*\)//g;
+
+  $content =~ s/[(].*[)]//gxms;
   return $content;
 };
 
 private_method p_cleanDuration => sub {
   my $value = shift;
-  $value =~ s/min\.//gi;
+  $value =~ s/min[.]//gixms;
   $value = trim($value);
-  
+
   if ( looks_like_number($value) ){
-    return $value    
-  } 
-  return undef;
+    return $value;
+  }
+  return;
 };
 
 private_method p_cleanPerson => sub {
   my $value = shift;
-     
-  my @persons = split(',', $value);
-  @persons = map (trim (p_removeTextBetweenParenthesis($_) ), @persons);
+
+  my @persons = split m/,/xms, $value;
+  @persons = map {trim (p_removeTextBetweenParenthesis($_) )} @persons;
   return \@persons;
 };
 
 private_method p_cleanGenre => sub {
   my ($value, $field) = @_;
-  
+
   my $pos = $field eq 'genre' ? 0 : 1;
-  my @list = split(/\|/, $value);
-  
+  my @list = split m/[|]/xms, $value;
+
   if ( defined $list[$pos]){
-    my @genres = trim ( split(/\./, $list[$pos] ) );  
+    my @genres = trim ( split m/[.]/xms, $list[$pos] );
     return \@genres;
-  }   
-  return undef;
+  }
+  return;
 };
 
 private_method p_cleanStudio => sub {
   my ($value, $field) = @_;
-  
+
   my $pos = $field eq 'studio' ? 0 : 1;
-  my @list = split(/\. Producer: /, $value);
-  
+  my @list = split m/[.]\sProducer: /xms, $value;
+
   my @studio = ();
   if (not defined $list[$pos]){
-    return undef;
+    return;
   } else {
-    @studio = trim ( split(/ \/ /, $list[$pos] ) );
-    return \@studio;  
-  } 
+    @studio = trim ( split m{ / }xms, $list[$pos] );
+    return \@studio;
+  }
 };
 
 =head1 AUTHOR
 
 William Belle, C<< <william.belle at gmail.com> >>
 
-=head1 BUGS
+=head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests to C<bug-filmaffinity-userrating at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=FilmAffinity-UserRating>.  I will be notified, and then you'll
