@@ -3,26 +3,41 @@ package FilmAffinity::Utils;
 use strict;
 use warnings;
 
+use Readonly;
 use LWP::RobotUA;
 
-=head1 NAME - FilmAffinity::Utils
+=head1 NAME
 
-Utils for FilmAffinity
+FilmAffinity::Utils - Utils for FilmAffinity
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
-require Exporter;
+=head1 SYNOPSIS
 
-our @ISA    = qw/Exporter/;
-our @EXPORT = qw/demoronize buildRobot data2tsv/;
+  use FilmAffinity::Utils;
 
-=head1 EXPORT
+  my $string = demoronize($string);
+  my $ua = buildRobot($delay);
+  my $tsv = data2tsv($data);
+  
+=head1 DESCRIPTION
+
+Several utilities functions
+
+=cut
+
+use base 'Exporter';
+our @EXPORT_OK = qw/demoronize buildRobot data2tsv/;
+
+Readonly::Scalar my $SECONDS => 60;
+
+=head1 SUBROUTINES/METHODS
 
 =head2 demoronize
 
@@ -38,26 +53,26 @@ sub demoronize {
   return $str unless defined $str;
 
   my $demoronizeReplaceMap = {
-    '\x{201A}|\x82'   => ',',   # 82, SINGLE LOW-9 QUOTATION MARK
-    '\x{201E}|\x84'   => ',,',  # 84, DOUBLE LOW-9 QUOTATION MARK
-    '\x{2026}|\x85'   => '...', # 85, HORIZONTAL ELLIPSIS
-    '\x{02C6}|\x88'   => '^',   # 88, MODIFIER LETTER CIRCUMFLEX ACCENT
-    '\x{2018}|\x91'   => '`',   # 91, LEFT SINGLE QUOTATION MARK
-    '\x{2019}|\x92'   => "'",   # 92, RIGHT SINGLE QUOTATION MARK
-    '\x{201C}|\x93'   => '"',   # 93, LEFT DOUBLE QUOTATION MARK
-    '\x{201D}|\x94'   => '"',   # 94, RIGHT DOUBLE QUOTATION MARK
-    '\x{2022}|\x95|•' => '*',   # 95, BULLET
-    '\x{2013}|\x96'   => '-',   # 96, EN DASH
-    '\x{2014}|\x97'   => '-',   # 97, EM DASH
-    '\x{2039}|\x8B'   => '<',   # 8B, SINGLE LEFT-POINTING ANGLE QUOTATION MARK
-    '\x{203A}|\x9B'   => '>',   # 9B, SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
+    q{\x{201A}|\x82}   => q{,},   # 82, SINGLE LOW-9 QUOTATION MARK
+    q{\x{201E}|\x84}   => q{,,},  # 84, DOUBLE LOW-9 QUOTATION MARK
+    q{\x{2026}|\x85}   => q{...}, # 85, HORIZONTAL ELLIPSIS
+    q{\x{02C6}|\x88}   => q{^},   # 88, MODIFIER LETTER CIRCUMFLEX ACCENT
+    q{\x{2018}|\x91}   => q{`},   # 91, LEFT SINGLE QUOTATION MARK
+    q{\x{2019}|\x92}   => q{'},   # 92, RIGHT SINGLE QUOTATION MARK
+    q{\x{201C}|\x93}   => q{"},   # 93, LEFT DOUBLE QUOTATION MARK
+    q{\x{201D}|\x94}   => q{"},   # 94, RIGHT DOUBLE QUOTATION MARK
+    q{\x{2022}|\x95|•} => q{*},   # 95, BULLET
+    q{\x{2013}|\x96}   => q{-},   # 96, EN DASH
+    q{\x{2014}|\x97}   => q{-},   # 97, EM DASH
+    q{\x{2039}|\x8B}   => q{<},   # 8B, SINGLE LEFT-POINTING ANGLE QUOTATION MARK
+    q{\x{203A}|\x9B}   => q{>},   # 9B, SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
   };
-  
-  foreach my $replace ( keys( %{$demoronizeReplaceMap} ) ) {
-      my $replacement = $demoronizeReplaceMap->{$replace};
-      $str =~ s/$replace/$replacement/g;
+
+  foreach my $replace ( keys %{$demoronizeReplaceMap} ) {
+    my $replacement = $demoronizeReplaceMap->{$replace};
+    $str =~ s/$replace/$replacement/xmsg;
   }
-  
+
   return $str;
 }
 
@@ -69,13 +84,13 @@ Returns a LWP::RobotUA for web requests
 
 sub buildRobot {
   my ($delay) = shift;
-  
-  my $ua = LWP::RobotUA->new("FilmAffinity-Bot/$VERSION", 'me@foo.com');
-  $ua->timeout(60);
-  $ua->env_proxy;  
-  $ua->delay($delay/60); 
-  
-  return $ua; 
+
+  my $ua = LWP::RobotUA->new( "FilmAffinity-Bot/$VERSION", 'me@foo.com' );
+  $ua->timeout($SECONDS);
+  $ua->env_proxy;
+  $ua->delay( $delay / $SECONDS );
+
+  return $ua;
 }
 
 =head2 data2tsv
@@ -87,20 +102,19 @@ Returns a tsv string
 =cut
 
 sub data2tsv {
-  my ( $data ) = shift;
-  
+  my ($data) = shift;
+
   my $tsvString;
-  foreach my $mov ( sort { p_sortByRatings($data) } keys %{$data}){
-    $tsvString .= $mov ."\t" . 
-                  $data->{$mov}{'title'} . "\t" . 
-                  $data->{$mov}{'rating'}."\n"; 
+  foreach my $mov ( sort { p_sortByRatings($data) } keys %{$data} ) {
+    $tsvString .= $mov . "\t" . $data->{$mov}{'title'} . "\t"
+      . $data->{$mov}{'rating'} . "\n";
   }
-  
-  return $tsvString; 
+
+  return $tsvString;
 }
 
 sub p_sortByRatings {
-  my ($ref_movies) = @_;  
+  my ($ref_movies) = @_;
   return $ref_movies->{$b}{'rating'} <=> $ref_movies->{$a}{'rating'};
 }
 
@@ -108,7 +122,7 @@ sub p_sortByRatings {
 
 William Belle, C<< <william.belle at gmail.com> >>
 
-=head1 BUGS
+=head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests to C<bug-filmaffinity-userrating at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=FilmAffinity-UserRating>.  I will be notified, and then you'll
@@ -158,4 +172,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of FilmAffinity::Utils
\ No newline at end of file
+1;    # End of FilmAffinity::Utils
